@@ -24,6 +24,7 @@ from velbusaio.channels import (
     Temperature,
     ThermostatChannel,
 )
+from velbusaio.command_registry import commandRegistry
 from velbusaio.const import CHANNEL_LIGHT_VALUE, CHANNEL_MEMO_TEXT, PRIORITY_LOW
 from velbusaio.helpers import handle_match, keys_exists
 from velbusaio.messages.blind_status import BlindStatusMessage, BlindStatusNgMessage
@@ -42,6 +43,9 @@ from velbusaio.messages.channel_name_part3 import (
     ChannelNamePart3Message2,
     ChannelNamePart3Message3,
 )
+from velbusaio.messages.channel_name_request import (
+    COMMAND_CODE as CHANNEL_NAME_REQUEST_COMMAND_CODE,
+)
 from velbusaio.messages.channel_name_request import ChannelNameRequestMessage
 from velbusaio.messages.clear_led import ClearLedMessage
 from velbusaio.messages.counter_status import CounterStatusMessage
@@ -255,7 +259,12 @@ class Module:
             _update_buttons = False
             for channel_types in self._data["Channels"]:
                 if keys_exists(self._data, "Channels", channel_types, "Type"):
-                    if self._data["Channels"][channel_types]["Type"] == "Button":
+                    if (
+                        self._data["Channels"][channel_types]["Type"] == "Button"
+                        or self._data["Channels"][channel_types]["Type"] == "Sensor"
+                        or self._data["Channels"][channel_types]["Type"]
+                        == "ButtonCounter"
+                    ):
                         _update_buttons = True
                         break
             if _update_buttons:
@@ -302,6 +311,14 @@ class Module:
             await self._channels[CHANNEL_LIGHT_VALUE].update(
                 {"cur": message.light_value}
             )
+            await self._channels[1].update({"closed": message.dark})
+            await self._channels[2].update({"closed": message.light})
+            await self._channels[3].update({"closed": message.motion1})
+            await self._channels[4].update({"closed": message.light_motion1})
+            await self._channels[5].update({"closed": message.motion2})
+            await self._channels[6].update({"closed": message.light_motion2})
+            await self._channels[7].update({"closed": message.low_temp_alarm})
+            await self._channels[8].update({"closed": message.high_temp_alarm})
         elif isinstance(message, UpdateLedStatusMessage):
             for channel_id in range(1, 9):
                 channel = self._translate_channel_name(channel_id + _channel_offset)
@@ -503,7 +520,10 @@ class Module:
             msg.channels = 0xFF
             await self._writer(msg)
         else:
-            msg = ChannelNameRequestMessage(self._address)
+            msg_type = commandRegistry.get_command(
+                CHANNEL_NAME_REQUEST_COMMAND_CODE, self.get_type()
+            )
+            msg = msg_type(self._address)
             msg.priority = PRIORITY_LOW
             msg.channels = list(range(1, (self.number_of_channels() + 1)))
             await self._writer(msg)
